<?php

namespace backend\controllers;

use Yii;
use backend\models\Termin;
use backend\models\TerminSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use backend\models\TerminLang;
use backend\models\TerminStructure;
use yii\filters\AccessControl;

/**
 * TerminController implements the CRUD actions for Termin model.
 */
class TerminController extends Controller
{
 public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'except' => ['login', 'error', 'index', 'create', 'update'],
                'rules' => [
                    [
                        'allow' => true,
                        'roles' => ['admin']
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'logout' => ['post'],
                    'delete-req' => ['post']
                ],
            ],
        ];
    }

    /**
     * Lists all Termin models.
     * @return mixed
     */
    public function actionIndex()
    { 
        $searchModel = new TerminSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single Termin model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Termin model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new Termin();
        $model_lang = new TerminLang();

        if ($model->load(Yii::$app->request->post())
            && $model_lang->load(Yii::$app->request->post())) 
        { 
            $model->save();
            $model_lang->termin_id = $model->termin_id;
            $model_lang->save();

            return $this->redirect(['view', 'id' => $model->termin_id]); 
        } 
        else 
        {
            return $this->render('create', [
                'model' => $model,
                'model_lang' => $model_lang,
            ]);
        }
    }

    /**
     * Updates an existing Termin model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);
        $model_lang = TerminLang::findOne($id);
        $model_pid = TerminStructure::findOne($id)->getRelation('terminPid')->one();
        
        //var_dump(Yii::$app->request->post());
        //var_dump($model_pid->termin->termin_id); die;
 
        if ($model->load(Yii::$app->request->post())
            && $model_lang->load(Yii::$app->request->post())
            && $model_pid->load(Yii::$app->request->post())
        ) 
        {    
            $model->save();
            $model_lang->save();
            $model_pid->termin_pid = $model_pid->termin->termin_id;
 
            return $this->redirect(['view', 'id' => $model->termin_id]); 
        } 
        else 
        {
            return $this->render('update', [
                'model' => $model,
                'model_lang' => $model_lang,
                'model_pid' => $model_pid,
            ]);
        }
    }

    /**
     * Deletes an existing Termin model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the Termin model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Termin the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Termin::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}
