<?php

namespace frontend\controllers;

use Yii;
use frontend\models\OptionValues;
use frontend\models\OptionValuesSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;

/**
 * OptionValuesController implements the CRUD actions for OptionValues model.
 */
class OptionValuesController extends Controller
{
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['post'],
                ],
            ],
        ];
    }

    /**
     * Lists all OptionValues models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new OptionValuesSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single OptionValues model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new OptionValues model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $post = \Yii::$app->request->post();
        if(is_array($post['OptionValues']['option_value_text'])) {
            $ok = 0;
            $first = 0;
            $id = 0;
            $models = array();
            foreach($post['OptionValues']['option_value_text'] as $lang => $value) {
                $models[$lang] = new OptionValues();
                $models[$lang]->load(Yii::$app->request->post());
                $models[$lang]->option_language_id = $lang;
                $models[$lang]->option_value_text = $value;
                if($first && $id) {
                    $models[$lang]->option_value_parent = $id;
                }
                if($models[$lang]->save()) {
                    $ok = 1;
                    if(!$first) {
                        $first = 1;
                        $id = $models[$lang]->option_value_id;
                    }
                } else {
                    unset($models[$lang]);
                }
            }
            if($ok) {
                return $this->redirect(['view', 'id' => $id]);
            }
        }
        $model = new OptionValues();
        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->option_value_id]);
        } else {
            return $this->render('create', [
               'model' => $model,
            ]);
        }   
    }

    /**
     * Updates an existing OptionValues model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->option_value_id]);
        } else {
            return $this->render('update', [
                'model' => $model,
            ]);
        }
    }

    /**
     * Deletes an existing OptionValues model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the OptionValues model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return OptionValues the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = OptionValues::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}
