<?php
namespace frontend\controllers;

use Yii;
use common\models\LoginForm;
use frontend\models\PasswordResetRequestForm;
use frontend\models\ResetPasswordForm;
use frontend\models\SignupForm;
use frontend\models\ContactForm;
use frontend\models\Options;
use frontend\models\OptionValues;
use yii\base\InvalidParamException;
use yii\web\BadRequestHttpException;
use yii\web\Controller;
use yii\filters\VerbFilter;
use yii\filters\AccessControl;
use frontend\models\OptionsToValues;
use yii\validators\EmailValidator;
use common\models\User;
use yii\helpers\VarDumper;
use common\models\Page; 
use frontend\models\Option;
use common\models\Social;


/**
 * Site controller
 */
class SiteController extends Controller
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'only' => ['logout', 'signup', 'index'],
                'rules' => [
                    [
                        'actions' => ['signup'],
                        'allow' => true,
                        'roles' => ['?'],
                    ],
                    [
                        'actions' => ['logout'],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                    [
                        'actions' => ['index'],
                        'allow' => true,
                        'roles' => ['@'],
                    ]
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'logout' => ['post'],
                ],
            ],
             'eauth' => [
                        // required to disable csrf validation on OpenID requests
                        'class' => \nodge\eauth\openid\ControllerBehavior::className(),
                        'only' => ['login'],
                    ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => 'yii\web\ErrorAction',
            ],
            'captcha' => [
                'class' => 'yii\captcha\CaptchaAction',
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null,
            ],
        ];
    }

    /**
     * Displays homepage.
     *
     * @return mixed
     */
    public function actionIndex()
    {
        return $this->render('index'); 
    }
    
    /**
     * ===================
     * ==== BASIC YII ====
     * ===================
     */

    /**
     * Logs in a user.
     *
     * @return mixed
     */
    public function actionLogin()
    {

    // creat new model table Social and new model User
    $social = new Social();
    $user = new User();
        
    $serviceName = Yii::$app->getRequest()->getQueryParam('service');

        if (isset($serviceName)) {
            /** @var $eauth \nodge\eauth\ServiceBase */
            $eauth = Yii::$app->get('eauth')->getIdentity($serviceName);
            $eauth->setRedirectUrl(Yii::$app->getUser()->getReturnUrl());
            $eauth->setCancelUrl(Yii::$app->getUrlManager()->createAbsoluteUrl('site/login'));

            try {
                if ($eauth->authenticate()) {
                    $identity = User::findByEAuth($eauth);
                    Yii::$app->getUser()->login($identity);

                    //Save date get social network in database
                    if (! $social::find()->where(['social_user_id' => $identity[profile][id], 'social_name' => $identity[profile][service]])->exists()) {
                        $name = explode(' ',$identity[profile][name]);
                        $user->firstname = $name[0];
                        $user->lastname = $name[1];
                        $user->id_system_date = date("d.m.y.H:i:s");
                        $user->save();
                        $social->social_name = $identity[profile][service];
                        $social->social_user_id = $identity[profile][id];
                        $social->user_id = $user->id;
                        $social->validate();
                        $social->errors;
                        $social->save();
                    }

                    // special redirect with closing popup window
                    $eauth->redirect();
                }
                else {
                    // close popup window and redirect to cancelUrl
                    $eauth->cancel();
                }
            }
            catch (\nodge\eauth\ErrorException $e) {
                // save error to show it later
                Yii::$app->getSession()->setFlash('error', 'EAuthException: '.$e->getMessage());

                // close popup window and redirect to cancelUrl
//              $eauth->cancel();
                $eauth->redirect($eauth->getCancelUrl());
            }
        }
        
        
        
        
        if (!\Yii::$app->user->isGuest) {
            return $this->goHome();
        }

        $model = new LoginForm();
        if ($model->load(Yii::$app->request->post()) && $model->login()) {
            return $this->goBack();
        } else {
            return $this->render('login', [
                'model' => $model,
            ]);
        }
    }

    /**
     * Logs out the current user.
     *
     * @return mixed
     */
    public function actionLogout()
    {
        Yii::$app->user->logout();

        return $this->goHome();
    }
 
    /**
     * Displays contact page.
     *
     * @return mixed
     */
    public function actionContact()
    {   
        Yii::$app->user->logout();
        $identity = Yii::$app->getUser()->getIdentity();
        var_dump($identity[profile]);
        die();
        
        $model = new ContactForm();
        if ($model->load(Yii::$app->request->post()) && $model->validate()) {
            if ($model->sendEmail(Yii::$app->params['adminEmail'])) {
                Yii::$app->session->setFlash('success', 'Thank you for contacting us. We will respond to you as soon as possible.');
            } else {
                Yii::$app->session->setFlash('error', 'There was an error sending email.');
            }

            return $this->refresh();
        } else {
            return $this->render('contact', [
                'model' => $model,
            ]);
        }
    }

    /**
     * Signs user up.
     *
     * @return mixed
     */
    public function actionSignup()
    {
        $model = new SignupForm();
        if ($model->load(Yii::$app->request->post())) {
            if ($user = $model->signup()) {
                if (Yii::$app->getUser()->login($user)) {
                    return $this->goHome();
                }
            }
        }

        return $this->render('signup', [
            'model' => $model,
        ]);
    }
    
    /**
     * Requests password reset.
     *
     * @return mixed
     */   
    public function actionRequestPasswordReset()
    {
        $model = new PasswordResetRequestForm();
        if ($model->load(Yii::$app->request->post()) && $model->validate()) {
            if ($model->sendEmail()) {
                Yii::$app->session->setFlash('success', 'Check your email for further instructions.');

                return $this->goHome();
            } else {
                Yii::$app->session->setFlash('error', 'Sorry, we are unable to reset password for email provided.');
            }
        }

        return $this->render('requestPasswordResetToken', [
            'model' => $model,
        ]);
    }

    /**
     * Resets password.
     *
     * @param string $token
     * @return mixed
     * @throws BadRequestHttpException
     */
    public function actionResetPassword($token)
    {
        try {
            $model = new ResetPasswordForm($token);
        } catch (InvalidParamException $e) {
            throw new BadRequestHttpException($e->getMessage());
        }

        if ($model->load(Yii::$app->request->post()) && $model->validate() && $model->resetPassword()) {
            Yii::$app->session->setFlash('success', 'New password was saved.');

            return $this->goHome();
        }

        return $this->render('resetPassword', [
            'model' => $model,
        ]);
    }

    public function actionOptions() {
        $option_model = new Options();
        $option_list = $option_model->find()->where(1)->all();
        $option_values = array();
        $post = \Yii::$app->request->post();
        
        if(!empty(\Yii::$app->request->post())) {
            $options_to_values = array();
            $hasErrors = false;
            foreach($post['options'] as $key => $val) {
                $options_to_values[$key] = new OptionsToValues();
                $options_to_values[$key]['option_id'] = $val['option_id'];
                $options_to_values[$key]->loadDefaultValues();
                if($options_to_values[$key]->save()) {
                    $option_values[$key] = new OptionValues();
                    $option_values[$key]['option_value_id'] = $options_to_values[$key]->getAttribute('option_value_id');
                    $option_values[$key]['option_value_text'] = $val['option_value'];
                    if($options_to_values[$key]->option->getAttribute('option_translatable') == 0 || empty($val['option_language_id'])) {
                        $option_values[$key]['option_language_id'] = 0;
                    } else {
                        $option_values[$key]['option_language_id'] = $val['option_language_id'];
                    }
                    if(!$option_values[$key]->save()) {  
                        $options_to_values[$key]->delete();
                        $hasErrors = true;
                    }
                }
            }
            if(hasErrors) {
                $data['option_values'] = $option_values;
                return $this->render('options', ['options' => $data, 'post' => $post]);
            } else {
                var_dump($data);
            }
        } else {
            foreach($option_list as $index => $option) {
                $option_values[$option->getAttribute('option_id')] = new OptionValues();
            }
            $data['option_values'] = $option_values;
            return $this->render('options', ['options' => $data, 'post' => $post]);
        }
    }
    
    public function actionFeedback() {
    	$form[0] = Option::create(\Yii::$app->request->post(), 'Feedback', 1, [['name' => 'one_name', 'template' => 'text', 'translate' => false], ['name' => 'phone', 'template' => 'text', 'translate' => false], ['name' => 'message', 'template' => 'text', 'translate' => false]], false);
    	if($form[0]['success'] == false) {
    		return $this->render('feedback', ['forms' => $form]);
    	} else {
    		return $this->render('index');
    	}
    }
}
